[![build](https://github.com/ihmeuw-msca/dimsm/actions/workflows/build.yml/badge.svg)](https://github.com/ihmeuw-msca/dimsm/actions/workflows/build.yml)
[![pypi](https://badge.fury.io/py/dimsm.svg)](https://badge.fury.io/py/dimsm)

# Dimension Smoother

Kalman based smoother, smoothing data across different dimensions.

## Install

To install the `dimsm` package do

```
pip install dimsm
```

If want to install the package with experimental features do

```
pip install git+https://github.com/ihmeuw-msca/dimsm.git@develop
```

## Example

* `examples/1d_smoother.py`: Simple 1D smoother example with sinusoidal curve
